@@ -7,7 +7,8 @@ from .models import Contract
 class ContractAdmin(admin.ModelAdmin):
     list_display = (
         'name', 'created', 'updated',
-        'created_by', 'updated_by', 'version'
+        'created_by', 'updated_by', 'version',
+        'webhook_active'
     )
     readonly_fields = (
         'created', 'updated', 'created_by', 'updated_by',
@@ -17,7 +18,7 @@ class ContractAdmin(admin.ModelAdmin):
     save_on_top = True
     ordering = ('-updated',)
     date_hierarchy = 'updated'
-    actions = ['manual_update']
+    actions = ['manual_update', 'apply_subresource_integrity']
 
     def save_model(self, request, obj, form, change):
         if not change:
@@ -35,5 +36,11 @@ class ContractAdmin(admin.ModelAdmin):
 
         self.message_user(request, "Contract update triggered.")
 
+    def apply_subresource_integrity(self, request, queryset):
+        from .tasks import apply_subresource_integrity
+
+        for contract in queryset:
+            apply_subresource_integrity.delay(contract.pk)
+
 
 admin.site.register(Contract, ContractAdmin)
